==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/NativeUIInput.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { NativeUIComponent } from "./NativeUIComponent";
import { NativeUIInputDisplayType_$type } from "./NativeUIInputDisplayType";
import { enumGetBox, EnumUtil, markType } from "./type";
import { NativeUIDisplayDensity_$type } from "./NativeUIDisplayDensity";
/**
 * @hidden
 */
var NativeUIInput = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUIInput, _super);
    function NativeUIInput() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.ar = null;
        _this.ap = null;
        return _this;
    }
    Object.defineProperty(NativeUIInput.prototype, "at", {
        get: function () {
            var a = this.o(0);
            return a == null ? 1 : EnumUtil.getEnumValue(NativeUIInputDisplayType_$type, a);
        },
        set: function (a) {
            this.ad(0, enumGetBox(NativeUIInputDisplayType_$type, a));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIInput.prototype, "aq", {
        get: function () {
            var a = this.o(1);
            return a == null ? 1 : EnumUtil.getEnumValue(NativeUIDisplayDensity_$type, a);
        },
        set: function (a) {
            this.ad(1, enumGetBox(NativeUIDisplayDensity_$type, a));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIInput.prototype, "au", {
        get: function () {
            var a = this.o(2);
            return a;
        },
        set: function (a) {
            this.ad(2, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIInput.prototype, "as", {
        get: function () {
            return this.ar;
        },
        set: function (a) {
            var b = this.ar;
            this.ar = a;
            if (this.ar != null) {
                this.w(0, this.ar);
            }
            else {
                this.ab(0, b);
            }
        },
        enumerable: false,
        configurable: true
    });
    NativeUIInput.$t = markType(NativeUIInput, 'NativeUIInput', NativeUIComponent.$);
    return NativeUIInput;
}(NativeUIComponent));
export { NativeUIInput };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/NativeUIInput.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { NativeUIComponent } from "./NativeUIComponent";
import { NativeUIInputDisplayType_$type } from "./NativeUIInputDisplayType";
import { enumGetBox, EnumUtil, markType } from "./type";
import { NativeUIDisplayDensity_$type } from "./NativeUIDisplayDensity";
/**
 * @hidden
 */
var NativeUIInput = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUIInput, _super);
    function NativeUIInput() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.av = null;
        _this.at = null;
        return _this;
    }
    Object.defineProperty(NativeUIInput.prototype, "ax", {
        get: function () {
            var a = this.o(0);
            return a == null ? 1 : EnumUtil.getEnumValue(NativeUIInputDisplayType_$type, a);
        },
        set: function (a) {
            this.af(0, enumGetBox(NativeUIInputDisplayType_$type, a));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIInput.prototype, "au", {
        get: function () {
            var a = this.o(1);
            return a == null ? 1 : EnumUtil.getEnumValue(NativeUIDisplayDensity_$type, a);
        },
        set: function (a) {
            this.af(1, enumGetBox(NativeUIDisplayDensity_$type, a));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIInput.prototype, "ay", {
        get: function () {
            var a = this.o(2);
            return a;
        },
        set: function (a) {
            this.af(2, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIInput.prototype, "aw", {
        get: function () {
            return this.av;
        },
        set: function (a) {
            var b = this.av;
            this.av = a;
            if (this.av != null) {
                this.x(0, this.av);
            }
            else {
                this.ad(0, b);
            }
        },
        enumerable: false,
        configurable: true
    });
    NativeUIInput.$t = markType(NativeUIInput, 'NativeUIInput', NativeUIComponent.$);
    return NativeUIInput;
}(NativeUIComponent));
export { NativeUIInput };
